from django.apps import AppConfig


class OneTimeLinkConfig(AppConfig):
    name = 'onetimelink'
    verbose_name = 'onetimelink'
